//*********************************************************************************************************
//
//
//  definitions, types, functions for Visual C#.NET         5.3101.13.2206
//
//
//*********************************************************************************************************

using System;
using System.Runtime.InteropServices;

namespace MELEC
{
    /// <summary>
    /// </summary>
    ///
    //*** RESULT STRUCTURE ***
    [StructLayout(LayoutKind.Sequential)]       // LAYOUT INFORMATION
    public struct MC07_S_RESULT
    {
        [MarshalAs(UnmanagedType.ByValArray, SizeConst = 4)]
        public ushort[] MC07_Result;
        public MC07_S_RESULT(ushort dummy)
        {
            MC07_Result = new ushort[4];
        }
    }

    //*** DATA STRUCTURE ***
    [StructLayout(LayoutKind.Sequential)]       // LAYOUT INFORMATION
    public struct MC07_S_DATA
    {
        [MarshalAs(UnmanagedType.ByValArray, SizeConst = 4)]
        public ushort[] MC07_Data;
        public MC07_S_DATA(ushort dummy)
        {
            MC07_Data = new ushort[4];
        }
    }

    //*** XY POSITION STRUCTURE ***
    public struct MC07_S_XY_POSITION
    {
        public int X;
        public int Y;
    }

    //*** SPEED SETUP STRUCTURE ***
    public struct MC07_S_SPEED_RATE
    {
        public uint FSpd;
        public uint HighSpeed;
        public uint LowSpeed;
        public uint EndLowSpeed;
        public uint SUArea;
        public uint SDArea;
        public uint URateNo;
        public uint DRateNo;
    }

    //*** ORG PARAMETER STRUCTURE ***
    public struct MC07_S_ORG_PARAM
    {
        public uint Spec;
        public uint MarginPulse;
        public uint LimitDelay;
        public uint ScanDelay;
        public uint PulseDelay;
        public uint CScanErrorPulse;
        public uint PulseErrorPulse;
        public uint OffsetPulse;
        public int PresetPulse;
    }

    public class MC07
    {
        public MC07()
        {
        }
        //*** DEFINITION ***
        public const ushort MC07_X =                            0;
        public const ushort MC07_Y =                            1;
        public const ushort MC07_Z =                            2;
        public const ushort MC07_A =                            3;
        public const ushort MC07_B =                            4;
        public const ushort MC07_C =                            5;

        public const ushort MC07_X1 =                           0;
        public const ushort MC07_Y1 =                           1;
        public const ushort MC07_Z1 =                           2;
        public const ushort MC07_A1 =                           3;
        public const ushort MC07_B1 =                           4;
        public const ushort MC07_C1 =                           5;
        public const ushort MC07_X2 =                           6;
        public const ushort MC07_Y2 =                           7;
        public const ushort MC07_Z2 =                           8;
        public const ushort MC07_A2 =                           9;
        public const ushort MC07_B2 =                           10;
        public const ushort MC07_C2 =                           11;

        public const ushort MC07_ORG0 =                         0;
        public const ushort MC07_ORG1 =                         1;
        public const ushort MC07_ORG2 =                         2;
        public const ushort MC07_ORG3 =                         3;
        public const ushort MC07_ORG4 =                         4;
        public const ushort MC07_ORG5 =                         5;
        public const ushort MC07_ORG10 =                        10;
        public const ushort MC07_ORG11 =                        11;
        public const ushort MC07_ORG12 =                        12;

        public const ushort MC07_INT_FACTOR_RDYINT =            0x0001;
        public const ushort MC07_INT_FACTOR_STBY =              0x0002;
        public const ushort MC07_INT_FACTOR_COMREG_EP =         0x0004;
        public const ushort MC07_INT_FACTOR_nCOMREG_FL =        0x0008;
        public const ushort MC07_INT_FACTOR_MAN =               0x0010;
        public const ushort MC07_INT_FACTOR_DALM =              0x0020;
        public const ushort MC07_INT_FACTOR_SS0 =               0x0040;
        public const ushort MC07_INT_FACTOR_SS1 =               0x0080;
        public const ushort MC07_INT_FACTOR_ADRINT =            0x0100;
        public const ushort MC07_INT_FACTOR_CNTINT =            0x0200;
        public const ushort MC07_INT_FACTOR_DFLINT =            0x0400;
        public const ushort MC07_INT_FACTOR_ERRINT =            0x0800;
        public const ushort MC07_INT_FACTOR_OUT2 =              0x1000;
        public const ushort MC07_INT_FACTOR_OUT3 =              0x2000;
        public const ushort MC07_INT_FACTOR_GPIO0 =             0x4000;
        public const ushort MC07_INT_FACTOR_GPIO1 =             0x8000;

        public const ushort MC07_CCW =                          0;
        public const ushort MC07_CW =                           1;

        public const ushort MC07_IO_IN_PORT1 =                  0x0000;
        public const ushort MC07_IO_IN_PORT2 =                  0x0001;
        public const ushort MC07_IO_OUT_PORT1 =                 0x0100;
        public const ushort MC07_IO_OUT_PORT2 =                 0x0101;
        
        //*** CallBack Function Delegate Declarations ***
        public delegate void PLPMC07CALLBACK( int Status, int UserData );

        //*** MPL Function Declarations ***
        [DllImport("Mc07A.dll", EntryPoint = "MC07_Reset")]
        public static extern bool Reset(ushort BoardNo, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_ReadBoardType")]
        public static extern bool ReadBoardType(ushort BoardNo, ref ushort pBoardType, ref ushort pVersion, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BOpen")]
        public static extern bool BOpen(ushort BoardNo, ushort Axis, ref uint phDev, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BClose")]
        public static extern bool BClose(uint hDev, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_ClrError")]
        public static extern bool ClrError(uint hDev, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_LWDrive")]
        public static extern bool LWDrive(uint hDev, ushort Cmd, ref uint pData, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_LWData")]
        public static extern bool LWData(uint hDev, ref uint pData, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_IWDrive")]
        public static extern bool IWDrive(uint hDev, ushort Cmd, ref MC07_S_DATA psData, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_IWData")]
        public static extern bool IWData(uint hDev, ref MC07_S_DATA psData, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BWDriveCommand")]
        public static extern bool BWDriveCommand(uint hDev, ref ushort pCmd, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BWDriveData1")]
        public static extern bool BWDriveData1(uint hDev, ref ushort pData, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BWDriveData2")]
        public static extern bool BWDriveData2(uint hDev, ref ushort pData, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BRStatus1")]
        public static extern bool BRStatus1(uint hDev, ref ushort pStatus, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BRStatus2")]
        public static extern bool BRStatus2(uint hDev, ref ushort pStatus, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BRStatus3")]
        public static extern bool BRStatus3(uint hDev, ref ushort pStatus, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BRStatus4")]
        public static extern bool BRStatus4(uint hDev, ref ushort pStatus, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BRStatus5")]
        public static extern bool BRStatus5(uint hDev, ref ushort pStatus, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_LRDrive")]
        public static extern bool LRDrive(uint hDev, ref uint pData, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_IRDrive")]
        public static extern bool IRDrive(uint hDev, ref MC07_S_DATA psData, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BRDriveData1")]
        public static extern bool BRDriveData1(uint hDev, ref ushort pData, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BRDriveData2")]
        public static extern bool BRDriveData2(uint hDev, ref ushort pData, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_LWRDrive")]
        public static extern bool LWRDrive(uint hDev, ushort Cmd, ref uint pWriteData, ref uint pReadData, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BWaitDriveCommand")]
        public static extern bool BWaitDriveCommand(uint hDev, ushort WaitTime, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BWaitComregNotFull")]
        public static extern bool BWaitComregNotFull(uint hDev, ushort WaitTime, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BIsWait")]
        public static extern bool BIsWait(uint hDev, ref ushort pWaitSts, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BBreakWait")]
        public static extern bool BBreakWait(uint hDev, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_SetSpeedRate")]
        public static extern bool SetSpeedRate(uint hDev, ushort ResolNo, ref MC07_S_SPEED_RATE psSpeedRate, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_ReadSpeedRate")]
        public static extern bool ReadSpeedRate(uint hDev, ref ushort pResolNo, ref MC07_S_SPEED_RATE psSpeedRate, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_McIncStrCp")]
        public static extern bool McIncStrCp(uint hDevX, uint hDevY, ushort DrvSpec, ref MC07_S_XY_POSITION psTargetPosition, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_McIncCirCp")]
        public static extern bool McIncCirCp(uint hDevX, uint hDevY, ushort DrvSpec, ushort Dir, ref MC07_S_XY_POSITION psCenterPosition, ref MC07_S_XY_POSITION psTargetPosition, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_GetCirShortPulse")]
        public static extern bool GetCirShortPulse(ushort Dir, ref MC07_S_XY_POSITION psCenterPosition, ref MC07_S_XY_POSITION psTargetPosition, ref int pShortPulse, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_GetCirCenterPosition")]
        public static extern bool GetCirCenterPosition(ref MC07_S_XY_POSITION psPassPosition, ref MC07_S_XY_POSITION psTargetPosition, ref ushort pDir, ref MC07_S_XY_POSITION psCenterPosition, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_IncFromAbs")]
        public static extern bool IncFromAbs(uint hDevX, uint hDevY, ref MC07_S_XY_POSITION psAbsPosition, ref MC07_S_XY_POSITION psIncPosition, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_ReadOrgStatus")]
        public static extern bool ReadOrgStatus(uint hDev, ref ushort pStatus, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_SetOrgSpec")]
        public static extern bool SetOrgSpec(uint hDev, ushort Spec, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_SetOrgMarginPulse")]
        public static extern bool SetOrgMarginPulse(uint hDev, uint MarginPulse, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_SetOrgDelay")]
        public static extern bool SetOrgDelay(uint hDev, ushort LimitDelay, ushort ScanDelay, ushort PulseDelay, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_SetOrgErrorPulse")]
        public static extern bool SetOrgErrorPulse(uint hDev, uint CScanErrorPulse, uint PulseErrorPulse, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_SetOrgOffsetPulse")]
        public static extern bool SetOrgOffsetPulse(uint hDev, uint OffsetPulse, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_SetOrgPresetPulse")]
        public static extern bool SetOrgPresetPulse(uint hDev, int PresetPulse, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_ReadOrgParam")]
        public static extern bool ReadOrgParam(uint hDev, ref MC07_S_ORG_PARAM psOrgParam, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_ResetOrgFlag")]
        public static extern bool ResetOrgFlag(uint hDev, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_Org")]
        public static extern bool Org(uint hDev, ushort OrgType, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_OpenDevInt")]
        public static extern bool OpenDevInt(uint hDev, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_CloseDevInt")]
        public static extern bool CloseDevInt(uint hDev, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_SetIntCallBack")]
        public static extern bool SetIntCallBack(uint hDev, uint IntFactor, PLPMC07CALLBACK Func, uint UserData, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_SetIntEvent")]
        public static extern bool SetIntEvent(uint hDev, uint IntFactor, uint hEvent, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_ReadIntStatus")]
        public static extern bool ReadIntStatus(uint hDev, uint IntFactor, ref uint pStatus, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_ClearIntSet")]
        public static extern bool ClearIntSet(uint hDev, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_IWHardConfig")]
        public static extern bool IWHardConfig(uint hDev, ushort Cmd, ref MC07_S_DATA psData, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BWHardConfigCommand")]
        public static extern bool BWHardConfigCommand(uint hDev, ref ushort pCmd, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BWHardConfigData1")]
        public static extern bool BWHardConfigData1(uint hDev, ref ushort pData, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BWHardConfigData2")]
        public static extern bool BWHardConfigData2(uint hDev, ref ushort pData, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BWHardConfigData3")]
        public static extern bool BWHardConfigData3(uint hDev, ref ushort pIData, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BRHardConfigStatus")]
        public static extern bool BRHardConfigStatus(uint hDev, ref ushort pStatus, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BRHardConfigPauseStatus")]
        public static extern bool BRHardConfigPauseStatus(uint hDev, ref ushort pStatus, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BRHardConfigStbyStatus")]
        public static extern bool BRHardConfigStbyStatus(uint hDev, ref ushort pStatus, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BRHardConfigSigStatus")]
        public static extern bool BRHardConfigSigStatus(uint hDev, ref ushort pStatus, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BRHardConfigData1")]
        public static extern bool BRHardConfigData1(uint hDev, ref ushort pData, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BRHardConfigData2")]
        public static extern bool BRHardConfigData2(uint hDev, ref ushort pData, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BRHardConfigData3")]
        public static extern bool BRHardConfigData3(uint hDev, ref ushort pData, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_SetData")]
        public static extern void SetData(uint Data, ref MC07_S_DATA psData);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_GetData")]
        public static extern uint GetData(ref MC07_S_DATA psData);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BPortOpen")]
        public static extern bool BPortOpen(ushort BoardNo, ushort IoPort, ref uint phPort, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BPortClose")]
        public static extern bool BPortClose(uint hPort, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BPortOut")]
        public static extern bool BPortOut(uint hPort, ref ushort pData, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_BPortIn")]
        public static extern bool BPortIn(uint hPort, ref ushort pData, ref MC07_S_RESULT psResult);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_Unsigned16")]
        public static extern ushort Unsigned16(short Data);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_Signed16")]
        public static extern short Signed16(ushort Data);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_Unsigned32")]
        public static extern uint Unsigned32(int Data);
        [DllImport("Mc07A.dll", EntryPoint = "MC07_Signed32")]
        public static extern int Signed32(uint Data);
    }
}