﻿Option Strict Off
Option Explicit On
Public Class Smp

    '****************************************************************************************************************
    '
    '   VB.NET Sample Program                               5.2801.22.2309                                   
    '
    '****************************************************************************************************************

    '****************************************************************************************************************
    '
    '   Definition of the variable
    '
    '****************************************************************************************************************
    Dim hDev As Integer                                         ' Device Handle
    Dim hInPort1 As Integer                                     ' IN Port Handle
    Dim hOutPort1 As Integer                                    ' OUT Port Handle

    '****************************************************************************************************************
    '
    '   Setting the condition of the button in drive condition.
    '
    '****************************************************************************************************************
    Private Sub ButtonDisable()
        Button_Close.Enabled = False
        Button_End.Enabled = False
        Button_Reset.Enabled = False
        Button_DataSet.Enabled = False
        Button_Ccw_Scan.Enabled = False
        Button_Cw_Scan.Enabled = False
        Button_Org.Enabled = False
        Button_Rtn.Enabled = False
        Button_Ccw_Index.Enabled = False
        Button_Cw_Index.Enabled = False
        Button_Demo.Enabled = False
        Button_ClrError.Enabled = False
    End Sub

    '****************************************************************************************************************
    '
    '   Setting the condition of the button in not drive condition.
    '
    '****************************************************************************************************************
    Private Sub ButtonEnable()
        Button_Close.Enabled = True
        Button_End.Enabled = False
        Button_Reset.Enabled = True
        Button_DataSet.Enabled = True
        Button_Ccw_Scan.Enabled = True
        Button_Cw_Scan.Enabled = True
        Button_Org.Enabled = True
        Button_Rtn.Enabled = True
        Button_Ccw_Index.Enabled = True
        Button_Cw_Index.Enabled = True
        Button_Demo.Enabled = True
        Button_ClrError.Enabled = True
    End Sub

    '****************************************************************************************************************
    '
    '   The stoppage factor of DRIVE that is shown with StopCode is displayed.
    '   Parameters StopCode ･･･ The variable where the drive stoppage factor is stored.
    '                           0:PASS  1:FSEND  2:SSEND  3:LSEND  4:SENSOR ERROR  5:ERROR PULSE ERROR  6:ADDRESS ERROR
    '                           7:FUNCTION ERROR(NO MESSAGE)
    '****************************************************************************************************************
    Private Sub StopCodeDisplay(ByVal StopCode As Byte)
        Select Case StopCode
            Case 1
                Label_Message.Text = "FSSTOP was input."

            Case 2
                Label_Message.Text = "SLSTOP was input."

            Case 3
                Label_Message.Text = "LIMIT was input."

            Case 4
                Label_Message.Text = "SENSOR ERROR was detected." & vbCrLf & "Please Click 'Clear Error'."

            Case 5
                Label_Message.Text = "ERROR PULSE ERROR was detected." & vbCrLf & "Please Click 'Clear Error'."

            Case 6
                Label_Message.Text = "ADDRESS ERROR was detected." & vbCrLf & "Please Click 'Clear Error'."
            Case 7

            Case Else
                Label_Message.Text = "Drive ended."
        End Select
    End Sub

    '********************************************************************************************************************
    '
    '   Check Status1 PORT.
    '   Parameter hDevice         ･･･ Device Handle
    '   Return Value              ･･･ TRUE: STATUS1 PORT BUSY BIT = 0 and ERROR BIT = 0
    '                                 FALSE: STATUS1 PORT BUSY BIT = 1 or ERROR BIT = 1
    '********************************************************************************************************************
    Private Function CheckStatus1(ByVal hDevice As Integer) As Boolean
        Dim sResult As New MC07_S_RESULT()
        Dim Status1 As Short
        Dim WData As Integer
        Dim RData As Integer
        Dim Cmd As Short

        sResult.Initialize()

        '*** CHECK STATUS1 BUSY BIT = 0 (WAIT TIME = 1000ms)***
        If (MC07_BWaitDriveCommand(hDevice, 1000, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_BWaitDriveCommand() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Function
        End If

        '*** READ STATUS1 ***
        If (MC07_BRStatus1(hDevice, Status1, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_BRStatus1() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Function
        End If

        '*** CHECK STATUS1 ERROR BIT = 0 ***
        If Status1 And &H10S Then
            '*** READ ERROR STATUS ***
            Cmd = &HD1S
            WData = 0
            If (MC07_LWRDrive(hDevice, Cmd, WData, RData, sResult) = False) Then
                Label_Message.Text = "It failed in MC07_LWRDrive(H'" & Hex(Cmd) & ") : MC07_Result(1)=" & Str(sResult.MC07_Result(1))
                Exit Function
            End If

            'GET DRIVE DATA1 PORT 
            RData = RData And &HFFFF

            Label_Message.Text = "STATUS1 ERROR = 1 : ERROR STATUS = H'" & Hex(RData) & System.Environment.NewLine _
                                    & "Plese click 'Clrear Error'"

            Exit Function

        End If

        CheckStatus1 = True

    End Function

    '****************************************************************************************************************
    '
    '   Waits until MCC07 becomes ready condition. Meantime position address of motor is displayed.
    '   Parameter hDevice         ･･･ Device Handle
    '             StopCode        ･･･ Pointer of the variable where the drive stoppage factor is stored.
    '                                 0:PASS  1:FSEND  2:SSEND  3:LSEND  4:SENSOR ERROR  5:ERROR PULSE ERROR  6:ADDRESS ERROR
    '                                 7:FUNCTION ERROR
    '             OriginDriveFlag ･･･ The Flag is shown that ORIGIN DRIVE executing or other DRIVE executing.
    '                                 True:ORIGIN DRIVE executing  False:other DRIVE executing
    '
    '****************************************************************************************************************
    Private Sub ReadyWait(ByVal hDevice As Integer, ByRef StopCode As Byte, ByVal OriginDriveFlag As Boolean)
        Dim sResult As New MC07_S_RESULT()
        Dim Status1 As Short

        sResult.Initialize()
        Do
            System.Windows.Forms.Application.DoEvents()
            Call NowAddressDisplay(hDevice)
            If (MC07_BRStatus1(hDevice, Status1, sResult) = False) Then
                Label_Message.Text = "It failed in MC07_BRStatus1() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

                StopCode = 7
                Exit Sub
            End If
        Loop While (Status1 And &H1S) <> 0

        Call NowAddressDisplay(hDevice)

        If OriginDriveFlag = True Then
            If (MC07_ReadOrgStatus(hDevice, Status1, sResult) = False) Then
                Label_Message.Text = "It failed in MC07_ReadOrgStatus() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

                StopCode = 7
                Exit Sub
            End If
            If Status1 And &H8000S Then
                StopCode = 6
            ElseIf Status1 And &H4000S Then
                StopCode = 5
            ElseIf Status1 And &H2000S Then
                StopCode = 4
            ElseIf Status1 And &H20S Then
                StopCode = 3
            ElseIf Status1 And &H40S Then
                StopCode = 2
            ElseIf Status1 And &H80S Then
                StopCode = 1
            Else
                StopCode = 0
            End If
        Else
            If Status1 And &H20S Then
                StopCode = 3
            ElseIf Status1 And &H40S Then
                StopCode = 2
            ElseIf Status1 And &H80S Then
                StopCode = 1
            Else
                StopCode = 0
            End If
        End If
    End Sub

    '****************************************************************************************************************
    '
    '   Position address of motor is displayed.
    '   Parameter hDevice ･･･ Device Handle
    '
    '****************************************************************************************************************
    Private Sub NowAddressDisplay(ByVal hDevice As Integer)
        Dim sResult As New MC07_S_RESULT()
        Dim WData As Integer
        Dim RData As Integer
        Dim Cmd As Short

        sResult.Initialize()

        '*** ADDRESS COUNTER READ COMMAND ***
        Cmd = &HD8S
        WData = 0
        If (MC07_LWRDrive(hDevice, Cmd, WData, RData, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_LWRDrive(H'" & Hex(Cmd) & ") : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If
        Label_NowAddress.Text = CStr(RData)
    End Sub

    '****************************************************************************************************************
    '
    '   The processing that the Open Button was clicked.
    '
    '****************************************************************************************************************
    Private Sub Command_Open_Click(ByVal eventSender As System.Object, ByVal eventArgs As System.EventArgs) Handles Button_Open.Click
        Dim sResult As New MC07_S_RESULT()

        sResult.Initialize()
        Label_Message.Text = ""

        If (MC07_BOpen(0, MC07_X, hDev, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_BOpen() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))
            Exit Sub
        End If

        Button_Open.Enabled = False
        Button_Close.Enabled = True
        Button_End.Enabled = False
        Button_Reset.Enabled = True
        Button_FastStop.Enabled = True
        Button_SlowStop.Enabled = True
        Button_DataSet.Enabled = True
        Button_Ccw_Scan.Enabled = True
        Button_Cw_Scan.Enabled = True
        Button_Org.Enabled = True
        Button_Rtn.Enabled = True
        Button_Ccw_Index.Enabled = True
        Button_Cw_Index.Enabled = True
        Button_Demo.Enabled = True
        Button_ClrError.Enabled = True
        NowAddressDisplay(hDev)                                 ' Position address is displayed.
    End Sub

    '****************************************************************************************************************
    '
    '   The processing that the Close Button was clicked.
    '
    '****************************************************************************************************************
    Private Sub Command_Close_Click(ByVal eventSender As System.Object, ByVal eventArgs As System.EventArgs) Handles Button_Close.Click
        Dim sResult As New MC07_S_RESULT()

        sResult.Initialize()
        Label_Message.Text = ""
        '*** DEVICE CLOSE ***
        If (MC07_BClose(hDev, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_BClose() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If
        Button_Open.Enabled = True
        Button_Close.Enabled = False
        Button_End.Enabled = True
        Button_Reset.Enabled = False
        Button_FastStop.Enabled = False
        Button_SlowStop.Enabled = False
        Button_DataSet.Enabled = False
        Button_Ccw_Scan.Enabled = False
        Button_Cw_Scan.Enabled = False
        Button_Org.Enabled = False
        Button_Rtn.Enabled = False
        Button_Ccw_Index.Enabled = False
        Button_Cw_Index.Enabled = False
        Button_Demo.Enabled = False
        Button_ClrError.Enabled = False
        Label_NowAddress.Text = "Please open the device."
    End Sub

    '********************************************************************************************************************
    '
    '   The processing that the Clear Error Button was clicked.
    '
    '********************************************************************************************************************
    Private Sub Command_ClrError_Click(ByVal eventSender As System.Object, ByVal eventArgs As System.EventArgs) Handles Button_ClrError.Click
        Dim sResult As New MC07_S_RESULT()

        sResult.Initialize()

        If (MC07_ClrError(hDev, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_ClrError() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        Label_Message.Text = "MC07_ClrError() succeed"

    End Sub

    '****************************************************************************************************************
    '
    '   The processing that the -Index Button was clicked.
    '
    '****************************************************************************************************************
    Private Sub Command_Ccw_Index_Click(ByVal eventSender As System.Object, ByVal eventArgs As System.EventArgs) Handles Button_Ccw_Index.Click
        Dim sResult As New MC07_S_RESULT()
        Dim Cmd As Short
        Dim LData As Integer
        Dim StopCode As Byte

        sResult.Initialize()
        Label_Message.Text = ""

        '*** INCREMENTAL INDEX DRIVE COMMAND ***
        If (CheckStatus1(hDev) = False) Then Exit Sub
        Cmd = &H14S
        LData = -3000
        If (MC07_LWDrive(hDev, Cmd, LData, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_LWDrive(H'" & Hex(Cmd) & ") : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        Call ButtonDisable()
        Call ReadyWait(hDev, StopCode, False)
        Call StopCodeDisplay(StopCode)
        Call ButtonEnable()
    End Sub

    '****************************************************************************************************************
    '
    '   The processing that the +Index Button was clicked.
    '
    '****************************************************************************************************************
    Private Sub Command_Cw_Index_Click(ByVal eventSender As System.Object, ByVal eventArgs As System.EventArgs) Handles Button_Cw_Index.Click
        Dim sResult As New MC07_S_RESULT()
        Dim Cmd As Short
        Dim LData As Integer
        Dim StopCode As Byte

        sResult.Initialize()
        Label_Message.Text = ""

        '*** INCREMENTAL INDEX DRIVE COMMAND ***
        If (CheckStatus1(hDev) = False) Then Exit Sub
        Cmd = &H14S
        LData = 3000
        If (MC07_LWDrive(hDev, Cmd, LData, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_LWDrive(H'" & Hex(Cmd) & ") : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        Call ButtonDisable()
        Call ReadyWait(hDev, StopCode, False)
        Call StopCodeDisplay(StopCode)
        Call ButtonEnable()
    End Sub

    '****************************************************************************************************************
    '
    '   The processing that the -Scan Button was clicked.
    '
    '****************************************************************************************************************
    Private Sub Command_Ccw_Scan_Click(ByVal eventSender As System.Object, ByVal eventArgs As System.EventArgs) Handles Button_Ccw_Scan.Click
        Dim sResult As New MC07_S_RESULT()
        Dim Cmd As Short
        Dim StopCode As Byte

        sResult.Initialize()
        Label_Message.Text = ""

        '*** -CCW SCAN DRIVE COMMAND ***
        If (CheckStatus1(hDev) = False) Then Exit Sub
        Cmd = &H13S
        If (MC07_BWDriveCommand(hDev, Cmd, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_BWDriveCommand(H'" & Hex(Cmd) & ") : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        Call ButtonDisable()
        Call ReadyWait(hDev, StopCode, False)
        Call StopCodeDisplay(StopCode)
        Call ButtonEnable()
    End Sub

    '****************************************************************************************************************
    '
    '   The processing that the +Scan Button was clicked.
    '
    '****************************************************************************************************************
    Private Sub Command_Cw_Scan_Click(ByVal eventSender As System.Object, ByVal eventArgs As System.EventArgs) Handles Button_Cw_Scan.Click
        Dim sResult As New MC07_S_RESULT()
        Dim Cmd As Short
        Dim StopCode As Byte

        sResult.Initialize()
        Label_Message.Text = ""

        '*** +CW SCAN DRIVE COMMAND ***
        If (CheckStatus1(hDev) = False) Then Exit Sub
        Cmd = &H12S
        If (MC07_BWDriveCommand(hDev, Cmd, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_BWDriveCommand(H'" & Hex(Cmd) & ") : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        Call ButtonDisable()
        Call ReadyWait(hDev, StopCode, False)
        Call StopCodeDisplay(StopCode)
        Call ButtonEnable()
    End Sub

    '****************************************************************************************************************
    '
    '   The processing that the Org Button was clicked.
    '
    '****************************************************************************************************************
    Private Sub Command_Org_Click(ByVal eventSender As System.Object, ByVal eventArgs As System.EventArgs) Handles Button_Org.Click
        Dim sResult As New MC07_S_RESULT()
        Dim StopCode As Byte

        sResult.Initialize()
        Label_Message.Text = ""
        '*** ORIGIN DRIVE ***
        If (CheckStatus1(hDev) = False) Then Exit Sub
        If (MC07_Org(hDev, MC07_ORG3, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_Org() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If
        Call ButtonDisable()
        Call ReadyWait(hDev, StopCode, True)                    ' Mcc07 Ready Wait
        Call StopCodeDisplay(StopCode)                          ' Stoppage factor of DRIVE is displayed.
        Call ButtonEnable()
    End Sub

    '****************************************************************************************************************
    '
    '   The processing that the Reset Button was clicked.
    '
    '****************************************************************************************************************
    Private Sub Command_Reset_Click(ByVal eventSender As System.Object, ByVal eventArgs As System.EventArgs) Handles Button_Reset.Click
        Dim sResult As New MC07_S_RESULT()
        Dim LData As Integer
        Dim Cmd As Short

        sResult.Initialize()
        Label_Message.Text = ""

        '*** ADDRESS COUNTER PRESET ***
        Cmd = &H80S
        LData = 0
        If (MC07_LWDrive(hDev, Cmd, LData, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_LWDrive(H'" & Hex(Cmd) & ") : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        Call NowAddressDisplay(hDev)
    End Sub

    '****************************************************************************************************************
    '
    '   The processing that the Rtn Button was clicked.
    '
    '****************************************************************************************************************
    Private Sub Command_Rtn_Click(ByVal eventSender As System.Object, ByVal eventArgs As System.EventArgs) Handles Button_Rtn.Click
        Dim sResult As New MC07_S_RESULT()
        Dim Cmd As Short
        Dim LData As Integer
        Dim StopCode As Byte

        sResult.Initialize()
        Label_Message.Text = ""

        '*** ABSOLUTE INDEX DRIVE COMMAND ***
        If (CheckStatus1(hDev) = False) Then Exit Sub
        Cmd = &H15S
        LData = 0
        If (MC07_LWDrive(hDev, Cmd, LData, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_LWDrive(H'" & Hex(Cmd) & ") : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If
        Call ButtonDisable()
        Call ReadyWait(hDev, StopCode, False)
        Call StopCodeDisplay(StopCode)
        Call ButtonEnable()
    End Sub

    '****************************************************************************************************************
    '
    '   The processing that the Stop Button was clicked.
    '
    '****************************************************************************************************************
    Private Sub Command_FastStop_Click(ByVal eventSender As System.Object, ByVal eventArgs As System.EventArgs) Handles Button_FastStop.Click
        Dim sResult As New MC07_S_RESULT()
        Dim Cmd As Short

        sResult.Initialize()
        '*** FAST STOP COMMAND ***
        Cmd = &HFFS
        If (MC07_BWDriveCommand(hDev, Cmd, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_BWDriveCommand(H'" & Hex(Cmd) & ") : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

    End Sub

    '****************************************************************************************************************
    '
    '   The processing that the Stop Button was clicked.
    '
    '****************************************************************************************************************
    Private Sub Command_SlowStop_Click(ByVal eventSender As System.Object, ByVal eventArgs As System.EventArgs) Handles Button_SlowStop.Click
        Dim sResult As New MC07_S_RESULT()
        Dim Cmd As Short

        sResult.Initialize()
        '*** SLOW STOP COMMAND ***
        Cmd = &HFES
        If (MC07_BWDriveCommand(hDev, Cmd, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_BWDriveCommand(H'" & Hex(Cmd) & ") : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

    End Sub


    '****************************************************************************************************************
    '
    '   The processing that the Demo Button was clicked.
    '
    '****************************************************************************************************************
    Private Sub Command_Demo_Click(ByVal eventSender As System.Object, ByVal eventArgs As System.EventArgs) Handles Button_Demo.Click
        Dim sResult As New MC07_S_RESULT()
        Dim n As Short
        Dim LData As Integer
        Dim Cmd As Short
        Dim StopCode As Byte

        sResult.Initialize()
        Label_Message.Text = ""
        Call ButtonDisable()

        If (CheckStatus1(hDev) = False) Then
            Call ButtonEnable()
            Exit Sub
        End If
        '*** ORIGIN DRIVE ***
        If (MC07_Org(hDev, MC07_ORG3, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_Org() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Call ButtonEnable()
            Exit Sub
        End If
        Call ReadyWait(hDev, StopCode, True)
        If StopCode <> 0 Then
            Call StopCodeDisplay(StopCode)
            Call ButtonEnable()
            Exit Sub
        End If

        '*** ADDRESS COUNTER PRESET ***
        Cmd = &H80S
        LData = 0
        If (MC07_LWDrive(hDev, Cmd, LData, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_LWDrive(H'" & Hex(Cmd) & ") : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Call ButtonEnable()
            Exit Sub
        End If

        '*** INCREMENTAL INDEX DRIVE 4 Times ***
        For n = 0 To 3
            If (CheckStatus1(hDev) = False) Then
                Call ButtonEnable()
                Exit Sub
            End If

            Cmd = &H14S
            LData = 4000
            If (MC07_LWDrive(hDev, Cmd, LData, sResult) = False) Then
                Label_Message.Text = "It failed in MC07_LWDrive(H'" & Hex(Cmd) & ") : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

                Call ButtonEnable()
                Exit Sub
            End If

            Call ReadyWait(hDev, StopCode, False)
            If StopCode <> 0 Then
                Call StopCodeDisplay(StopCode)
                Call ButtonEnable()
                Exit Sub
            End If
        Next

        '*** ABSOLUTE INDEX DRIVE ***
        If (CheckStatus1(hDev) = False) Then
            Call ButtonEnable()
            Exit Sub
        End If

        Cmd = &H15S
        LData = 30000
        If (MC07_LWDrive(hDev, Cmd, LData, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_LWDrive(H'" & Hex(Cmd) & ") : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Call ButtonEnable()
            Exit Sub
        End If

        Call ReadyWait(hDev, StopCode, False)
        If StopCode <> 0 Then
            Call StopCodeDisplay(StopCode)
            Call ButtonEnable()
            Exit Sub
        End If

        '*** ABSOLUTE INDEX DRIVE ***
        If (CheckStatus1(hDev) = False) Then
            Call ButtonEnable()
            Exit Sub
        End If

        Cmd = &H15S
        LData = 0
        If (MC07_LWDrive(hDev, Cmd, LData, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_LWDrive(H'" & Hex(Cmd) & ") : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Call ButtonEnable()
            Exit Sub
        End If

        Call ReadyWait(hDev, StopCode, False)
        Call StopCodeDisplay(StopCode)
        Call ButtonEnable()

    End Sub

    '****************************************************************************************************************
    '
    '   The processing that the Data Set Button was clicked.
    '
    '****************************************************************************************************************
    Private Sub Command_DataSet_Click(ByVal eventSender As System.Object, ByVal eventArgs As System.EventArgs) Handles Button_DataSet.Click
        Dim sResult As New MC07_S_RESULT()
        Dim LData As Integer
        Dim Cmd As Short

        sResult.Initialize()
        Label_Message.Text = ""

        '*** FSPD SET COMMAND       : 5000Hz ***
        If (CheckStatus1(hDev) = False) Then Exit Sub
        Cmd = &H5S
        LData = 5000
        If (MC07_LWDrive(hDev, Cmd, LData, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_LWDrive(H'" & Hex(Cmd) & ") : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        '*** JSPD SET COMMAND       : 1000Hz ***
        If (CheckStatus1(hDev) = False) Then Exit Sub
        Cmd = &HCS
        LData = 1000
        If (MC07_LWDrive(hDev, Cmd, LData, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_LWDrive(H'" & Hex(Cmd) & ") : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        '*** HIGH SPEED SET COMMAND ***
        If (CheckStatus1(hDev) = False) Then Exit Sub
        Cmd = &H6S
        LData = 5000 Or (&H3 << 16)           ' HSPD       : 5000Hz           RESOL No.  : 3
        If (MC07_LWDrive(hDev, Cmd, LData, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_LWDrive(H'" & Hex(Cmd) & ") : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        '*** LOW SPEED SET COMMAND ***
        If (CheckStatus1(hDev) = False) Then Exit Sub
        Cmd = &H7S
        LData = 1000 Or (1000 << 16)           ' LSPD       : 1000Hz           ELSPD      : 1000Hz
        If (MC07_LWDrive(hDev, Cmd, LData, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_LWDrive(H'" & Hex(Cmd) & ") : MC07_Result(1)=" & Str(sResult.MC07_Result(1))
            Exit Sub
        End If

        '*** RATE SET COMMAND ***
        If (CheckStatus1(hDev) = False) Then Exit Sub
        Cmd = &H8S
        LData = 200 Or (200 << 16)           ' UCYCLE     : 100μs            DCYCLE     : 100μs
        If (MC07_LWDrive(hDev, Cmd, LData, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_LWDrive(H'" & Hex(Cmd) & ") : MC07_Result(1)=" & Str(sResult.MC07_Result(1))
            Exit Sub
        End If

        '*** ORIGIN SPEC SET ***
        If (CheckStatus1(hDev) = False) Then Exit Sub
        If (MC07_SetOrgSpec(hDev, &H8000S, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_SetOrgSpec() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        '*** MARGIN PULSE            : 5 Pulse ***
        If (CheckStatus1(hDev) = False) Then Exit Sub
        If (MC07_SetOrgMarginPulse(hDev, 5, sResult) = False) Then
            Label_Message.Text = "It failed in MC07_SetOrgMarginPulse() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If


        Label_Message.Text = "DATA SET Succeed"


    End Sub

    '****************************************************************************************************************
    '
    '   The processing that the End Button was clicked.
    '
    '****************************************************************************************************************
    Private Sub Command_End_Click(ByVal eventSender As System.Object, ByVal eventArgs As System.EventArgs) Handles Button_End.Click
        End
    End Sub

    '****************************************************************************************************************
    '
    '   The processing that the Form was constructed.
    '
    '****************************************************************************************************************
    Private Sub Smp_Load(ByVal eventSender As System.Object, ByVal eventArgs As System.EventArgs) Handles MyBase.Load
        Button_Open.Enabled = True
        Button_Close.Enabled = False
        Button_End.Enabled = True
        Button_Reset.Enabled = False
        Button_FastStop.Enabled = False
        Button_SlowStop.Enabled = False
        Button_DataSet.Enabled = False
        Button_Ccw_Scan.Enabled = False
        Button_Cw_Scan.Enabled = False
        Button_Org.Enabled = False
        Button_Rtn.Enabled = False
        Button_Ccw_Index.Enabled = False
        Button_Cw_Index.Enabled = False
        Label_NowAddress.Text = "Please open the device."

        Label_Message_GenIO.Text = "Please open General-purpose IO."
        Button_OpenGenIO.Enabled = True
        Button_CloseGenIO.Enabled = False
        Button_ReadGenIn0.Enabled = False
        Button_GenOut0.Enabled = False
        Button_GenOut1.Enabled = False
        Button_GenOut2.Enabled = False
        Button_GenOut3.Enabled = False


    End Sub

    '****************************************************************************************************************
    '
    '   The processing that the Form was unload.
    '
    '****************************************************************************************************************
    Private Sub Smp_Closed(ByVal eventSender As System.Object, ByVal eventArgs As System.EventArgs) Handles MyBase.Closed
        Dim sResult As New MC07_S_RESULT()
        Dim Ret As Boolean

        sResult.Initialize()

        Ret = MC07_BClose(hDev, sResult)

        Ret = MC07_BPortClose(hInPort1, sResult)

        Ret = MC07_BPortClose(hOutPort1, sResult)


    End Sub

    '********************************************************************************************************************
    '
    '   The processing that the Open General-purpose IO was clicked.
    '
    '********************************************************************************************************************
    Private Sub Button_OpenGenIO_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button_OpenGenIO.Click
        Dim sResult As New MC07_S_RESULT()
        Dim Ret As Boolean
        Dim Data As Short

        sResult.Initialize()

        Label_Message_GenIO.Text = ""


        '*** BPORT OPEN ***
        If (MC07_BPortOpen(0, MC07_IO_IN_PORT1, hInPort1, sResult) = False) Then
            Label_Message_GenIO.Text = "It failed in MC07_BPortOpen() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        '*** BPORT OPEN ***
        If (MC07_BPortOpen(0, MC07_IO_OUT_PORT1, hOutPort1, sResult) = False) Then
            Label_Message_GenIO.Text = "It failed in MC07_BPortOpen() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            'Because it is avoided double BPort Open Error
            Ret = MC07_BPortClose(hInPort1, sResult)
            Exit Sub
        End If

        '*** READ BPORT OUT ***
        If (MC07_BPortIn(hOutPort1, Data, sResult) = False) Then
            Label_Message_GenIO.Text = "It failed in MC07_BPortIn() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            'Because it is avoided double BPort Open Error
            Ret = MC07_BPortClose(hInPort1, sResult)
            Ret = MC07_BPortClose(hOutPort1, sResult)
            Exit Sub
        End If

        If (Data And &H1S) Then Label_GenOut0.Text = "ON" Else Label_GenOut0.Text = "OFF"

        If (Data And &H2S) Then Label_GenOut1.Text = "ON" Else Label_GenOut1.Text = "OFF"

        If (Data And &H4S) Then Label_GenOut2.Text = "ON" Else Label_GenOut2.Text = "OFF"

        If (Data And &H8S) Then Label_GenOut3.Text = "ON" Else Label_GenOut3.Text = "OFF"

        '*** READ BPORT IN ***'
        Button_ReadGenIn0.Enabled = True
        Button_ReadGenIn0.PerformClick()

        Button_OpenGenIO.Enabled = False
        Button_CloseGenIO.Enabled = True
        Button_GenOut0.Enabled = True
        Button_GenOut1.Enabled = True
        Button_GenOut2.Enabled = True
        Button_GenOut3.Enabled = True

    End Sub

    '********************************************************************************************************************
    '
    '   The processing that the Close General-purpose IO was clicked.
    '
    '********************************************************************************************************************
    Private Sub Button_CloseGenIO_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button_CloseGenIO.Click

        Dim sResult As New MC07_S_RESULT()

        sResult.Initialize()

        '*** BPORT CLOSE ***
        If (MC07_BPortClose(hInPort1, sResult) = False) Then
            Label_Message_GenIO.Text = "It failed in MC07_BPortClose() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        '*** BPORT CLOSE ***
        If (MC07_BPortClose(hOutPort1, sResult) = False) Then
            Label_Message_GenIO.Text = "It failed in MC07_BPortClose() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        Label_Message_GenIO.Text = ""
        Label_GenOut0.Text = "" : Label_GenOut1.Text = "" : Label_GenOut2.Text = "" : Label_GenOut3.Text = ""
        Label_GenIn0.Text = "" : Label_GenIn1.Text = "" : Label_GenIn2.Text = "" : Label_GenIn3.Text = ""

        Button_OpenGenIO.Enabled = True
        Button_CloseGenIO.Enabled = False
        Button_ReadGenIn0.Enabled = False
        Button_GenOut0.Enabled = False
        Button_GenOut1.Enabled = False
        Button_GenOut2.Enabled = False
        Button_GenOut3.Enabled = False

    End Sub

    '********************************************************************************************************************
    '
    '   The processing that the General-purpose I/O OUT00 was clicked.
    '
    '********************************************************************************************************************
    Private Sub Button_GenOut0_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button_GenOut0.Click
        Dim sResult As New MC07_S_RESULT()
        Dim Data As Short

        sResult.Initialize()
        Label_Message_GenIO.Text = ""

        '*** READ BPORT OUT ***
        If (MC07_BPortIn(hOutPort1, Data, sResult) = False) Then
            Label_Message_GenIO.Text = "It failed in MC07_BPortIn() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        If (Data And &H1S) Then
            'ON -> OFF
            Data = Data And &HES
        Else
            'OFF -> ON
            Data = Data Or &H1S
        End If

        '*** BPORT OUT ***
        If (MC07_BPortOut(hOutPort1, Data, sResult) = False) Then
            Label_Message_GenIO.Text = "It failed in MC07_BPortOut() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        '*** READ BPORT OUT ***
        If (MC07_BPortIn(hOutPort1, Data, sResult) = False) Then
            Label_Message_GenIO.Text = "It failed in MC07_BPortIn() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        If (Data And &H1S) Then Label_GenOut0.Text = "ON" Else Label_GenOut0.Text = "OFF"

    End Sub

    '********************************************************************************************************************
    '
    '   The processing that the General-purpose I/O OUT01 was clicked.
    '
    '********************************************************************************************************************
    Private Sub Button_GenOut1_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button_GenOut1.Click
        Dim sResult As New MC07_S_RESULT()
        Dim Data As Short

        sResult.Initialize()
        Label_Message_GenIO.Text = ""

        '*** READ BPORT OUT ***
        If (MC07_BPortIn(hOutPort1, Data, sResult) = False) Then
            Label_Message_GenIO.Text = "It failed in MC07_BPortIn() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        If (Data And &H2S) Then
            'ON -> OFF
            Data = Data And &HDS
        Else
            'OFF -> ON
            Data = Data Or &H2S
        End If

        '*** BPORT OUT ***
        If (MC07_BPortOut(hOutPort1, Data, sResult) = False) Then
            Label_Message_GenIO.Text = "It failed in MC07_BPortOut() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        '*** READ BPORT OUT ***
        If (MC07_BPortIn(hOutPort1, Data, sResult) = False) Then
            Label_Message_GenIO.Text = "It failed in MC07_BPortIn() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        If (Data And &H2S) Then Label_GenOut1.Text = "ON" Else Label_GenOut1.Text = "OFF"


    End Sub

    '********************************************************************************************************************
    '
    '   The processing that the General-purpose I/O OUT02 was clicked.
    '
    '********************************************************************************************************************
    Private Sub Button_GenOut2_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button_GenOut2.Click
        Dim sResult As New MC07_S_RESULT()
        Dim Data As Short

        sResult.Initialize()
        Label_Message_GenIO.Text = ""

        '*** READ BPORT OUT ***
        If (MC07_BPortIn(hOutPort1, Data, sResult) = False) Then
            Label_Message_GenIO.Text = "It failed in MC07_BPortIn() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        If (Data And &H4S) Then
            'ON -> OFF
            Data = Data And &HBS
        Else
            'OFF -> ON
            Data = Data Or &H4S
        End If

        '*** BPORT OUT ***
        If (MC07_BPortOut(hOutPort1, Data, sResult) = False) Then
            Label_Message_GenIO.Text = "It failed in MC07_BPortOut() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        '*** READ BPORT OUT ***
        If (MC07_BPortIn(hOutPort1, Data, sResult) = False) Then
            Label_Message_GenIO.Text = "It failed in MC07_BPortIn() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        If (Data And &H4S) Then Label_GenOut2.Text = "ON" Else Label_GenOut2.Text = "OFF"


    End Sub

    '********************************************************************************************************************
    '
    '   The processing that the General-purpose I/O OUT03 was clicked.
    '
    '********************************************************************************************************************
    Private Sub Button_GenOut3_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button_GenOut3.Click
        Dim sResult As New MC07_S_RESULT()
        Dim Data As Short

        sResult.Initialize()
        Label_Message_GenIO.Text = ""

        '*** READ BPORT OUT ***
        If (MC07_BPortIn(hOutPort1, Data, sResult) = False) Then
            Label_Message_GenIO.Text = "It failed in MC07_BPortIn() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        If (Data And &H8S) Then
            'ON -> OFF
            Data = Data And &H7S
        Else
            'OFF -> ON
            Data = Data Or &H8S
        End If

        '*** BPORT OUT ***
        If (MC07_BPortOut(hOutPort1, Data, sResult) = False) Then
            Label_Message_GenIO.Text = "It failed in MC07_BPortOut() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        '*** READ BPORT OUT ***
        If (MC07_BPortIn(hOutPort1, Data, sResult) = False) Then
            Label_Message_GenIO.Text = "It failed in MC07_BPortIn() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        If (Data And &H8S) Then Label_GenOut3.Text = "ON" Else Label_GenOut3.Text = "OFF"

    End Sub

    '********************************************************************************************************************
    '
    '   The processing that the Read General-purpose IO was clicked.
    '
    '********************************************************************************************************************
    Private Sub Button_ReadGenIn0_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button_ReadGenIn0.Click
        Dim sResult As New MC07_S_RESULT()
        Dim Data As Short

        sResult.Initialize()
        Label_Message_GenIO.Text = ""

        '*** READ BPORT IN ***
        If (MC07_BPortIn(hInPort1, Data, sResult) = False) Then
            Label_Message_GenIO.Text = "It failed in MC07_BPortIn() : MC07_Result(1)=" & Str(sResult.MC07_Result(1))

            Exit Sub
        End If

        If (Data And &H1S) Then Label_GenIn0.Text = "ON" Else Label_GenIn0.Text = "OFF"

        If (Data And &H2S) Then Label_GenIn1.Text = "ON" Else Label_GenIn1.Text = "OFF"

        If (Data And &H4S) Then Label_GenIn2.Text = "ON" Else Label_GenIn2.Text = "OFF"

        If (Data And &H8S) Then Label_GenIn3.Text = "ON" Else Label_GenIn3.Text = "OFF"

    End Sub


End Class
